@@ -1,28 +1,14 @@
-/***************************************************************************
- *   Copyright (C) 2004, 2005 by Jakub Stachowski                          *
- *   qbast@go2.pl                                                          *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2004, 2005 Jakub Stachowski <qbast@go2.pl>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "dnssd.h"
 
 // io-slave
 #include "zeroconfurl.h"
-// KDE
+// KF
 #include <KLocalizedString>
 #include <KProtocolInfo>
 // Qt
@@ -130,10 +116,12 @@ void ZeroConfProtocol::listDir( const QUrl& url )
     switch (type)
     {
     case ZeroConfUrl::RootDir:
+        listCurrentDirEntry();
         serviceTypeBrowser = new ServiceTypeBrowser(zeroConfUrl.domain());
-        connect( serviceTypeBrowser, SIGNAL(serviceTypeAdded(QString)),
-                 SLOT(addServiceType(QString)) );
-        connect( serviceTypeBrowser, SIGNAL(finished()), SLOT(onBrowserFinished()) );
+        connect(serviceTypeBrowser, &ServiceTypeBrowser::serviceTypeAdded,
+                this, &ZeroConfProtocol::addServiceType);
+        connect(serviceTypeBrowser, &ServiceTypeBrowser::finished,
+                this, &ZeroConfProtocol::onBrowserFinished);
         serviceTypeBrowser->startBrowse();
         enterLoop();
         break;
@@ -143,10 +131,12 @@ void ZeroConfProtocol::listDir( const QUrl& url )
             error( ERR_SERVICE_NOT_AVAILABLE, zeroConfUrl.serviceType() );
             break;
         }
+        listCurrentDirEntry();
         serviceBrowser = new ServiceBrowser( zeroConfUrl.serviceType(), false, zeroConfUrl.domain() );
-        connect( serviceBrowser, SIGNAL(serviceAdded(KDNSSD::RemoteService::Ptr)),
-                 SLOT(addService(KDNSSD::RemoteService::Ptr)) );
-        connect( serviceBrowser, SIGNAL(finished()), SLOT(onBrowserFinished()) );
+        connect(serviceBrowser, &ServiceBrowser::serviceAdded,
+                this, &ZeroConfProtocol::addService);
+        connect(serviceBrowser, &ServiceBrowser::finished,
+                this, &ZeroConfProtocol::onBrowserFinished);
         serviceBrowser->startBrowse();
         enterLoop();
         break;
@@ -216,6 +206,13 @@ void ZeroConfProtocol::resolveAndRedirect( const ZeroConfUrl& zeroConfUrl )
     finished();
 }
 
+void ZeroConfProtocol::listCurrentDirEntry()
+{
+    UDSEntry entry;
+    feedEntryAsDir( &entry, QStringLiteral(".") );
+    listEntry(entry);
+}
+
 void ZeroConfProtocol::addServiceType( const QString& serviceType )
 {
     if (ServiceTypesAdded.contains(serviceType))
@@ -261,7 +258,7 @@ void ZeroConfProtocol::onBrowserFinished()
     }
     ServiceTypesAdded.clear();
 
-    emit leaveModality();
+    Q_EMIT leaveModality();
 }
 
 void ZeroConfProtocol::feedEntryAsDir( UDSEntry* entry, const QString& name, const QString& displayName )
@@ -277,7 +274,7 @@ void ZeroConfProtocol::feedEntryAsDir( UDSEntry* entry, const QString& name, con
 void ZeroConfProtocol::enterLoop()
 {
     QEventLoop eventLoop;
-    connect(this, SIGNAL(leaveModality()),&eventLoop, SLOT(quit()));
+    connect(this, &ZeroConfProtocol::leaveModality, &eventLoop, &QEventLoop::quit);
     eventLoop.exec(QEventLoop::ExcludeUserInputEvents);
 }
 
